@@ -1,5 +1,6 @@
-"""Utilities relative to operative systems."""
+"""Utilities relative to detecting operative systems."""
 import sys
+from .is_architecture import is_arm
 
 
 def is_macos() -> bool:
@@ -7,6 +8,11 @@ def is_macos() -> bool:
     return sys.platform == "darwin"
 
 
+def is_macos_with_arm() -> bool:
+    """Return whether OS is macOS with ARM Architecture (M1 and so on)."""
+    return is_macos() and is_arm()
+
+
 def is_windows() -> bool:
     """Return whether OS is Windows."""
     return sys.platform in ("win32", "cygwin")
